@@ -19,7 +19,6 @@ def ensemble_mean(
         torch.Tensor
 
     Examples:
-
         >>> function = lambda: torch.tensor([1.0, 2.0])
         >>> ensemble_mean(function, 5)
         tensor([1., 2.])
@@ -29,4 +28,8 @@ def ensemble_mean(
         >>> ensemble_mean(function, 5)
         tensor([ 0.4236, -0.0396])
     """
-    return torch.stack([function(*args, **kwargs) for _ in range(n_times)]).mean(dim=0)
+    if n_times == 1:
+        return function(*args, **kwargs)
+    else:
+        stack = torch.stack([function(*args, **kwargs) for _ in range(n_times)])
+        return stack.mean(dim=0)
