@@ -10,6 +10,9 @@ from .features import MaxLogMoneyness
 from .features import MaxMoneyness
 from .features import Moneyness
 from .features import PrevHedge
+from .features import Spot
 from .features import TimeToMaturity
+from .features import UnderlierSpot
+from .features import Variance
 from .features import Volatility
 from .features import Zeros
