@@ -8,13 +8,13 @@ from pfhedge._utils.doc import _set_docstring
 from pfhedge._utils.str import _format_float
 from pfhedge.nn.functional import european_binary_payoff
 
-from ..primary.base import Primary
+from ..primary.base import BasePrimary
+from .base import BaseDerivative
 from .base import BaseOption
-from .base import Derivative
 
 
 class EuropeanBinaryOption(BaseOption):
-    """A European binary option.
+    r"""European binary option.
 
     An American binary call option pays an unit amount of cash if and only if
     the underlying asset's price at maturity is equal or greater than the strike price.
@@ -25,12 +25,11 @@ class EuropeanBinaryOption(BaseOption):
     The payoff of an American binary call option is given by:
 
     .. math::
-
-        \\mathrm{payoff} =
-        \\begin{cases}
-            1 & (S \\geq K) \\\\
-            0 & (\\text{otherwise})
-        \\end{cases}
+        \mathrm{payoff} =
+        \begin{cases}
+            1 & (S \geq K) \\
+            0 & (\text{otherwise})
+        \end{cases}
 
     with :math:`S` being the underlying asset's price at maturity and
     :math:`K` being the strike price (`strike`) of the option
@@ -38,18 +37,17 @@ class EuropeanBinaryOption(BaseOption):
     The payoff of an American binary put option is given by:
 
     .. math::
-
-        \\mathrm{payoff} =
-        \\begin{cases}
-            1 & (S \\leq K) \\\\
-            0 & (\\text{otherwise})
-        \\end{cases}
+        \mathrm{payoff} =
+        \begin{cases}
+            1 & (S \leq K) \\
+            0 & (\text{otherwise})
+        \end{cases}
 
     .. seealso::
         :func:`pfhedge.nn.functional.european_binary_payoff`: Payoff function.
 
     Args:
-        underlier (:class:`Primary`): The underlying instrument of the option.
+        underlier (:class:`BasePrimary`): The underlying instrument of the option.
         call (bool, default=True): Specifies whether the option is call or put.
         strike (float, default=1): The strike price of the option.
         maturity (float, default=20/250) The maturity of the option.
@@ -60,7 +58,6 @@ class EuropeanBinaryOption(BaseOption):
         device (torch.device): The device where the simulated time-series are.
 
     Examples:
-
         >>> import torch
         >>> from pfhedge.instruments import BrownianStock
         >>> from pfhedge.instruments import EuropeanBinaryOption
@@ -77,7 +74,7 @@ class EuropeanBinaryOption(BaseOption):
 
     def __init__(
         self,
-        underlier: Primary,
+        underlier: BasePrimary,
         call: bool = True,
         strike: float = 1.0,
         maturity: float = 20 / 250,
@@ -113,11 +110,11 @@ class EuropeanBinaryOption(BaseOption):
 
 
 # Assign docstrings so they appear in Sphinx documentation
-_set_attr_and_docstring(EuropeanBinaryOption, "simulate", Derivative.simulate)
-_set_attr_and_docstring(EuropeanBinaryOption, "to", Derivative.to)
-_set_attr_and_docstring(EuropeanBinaryOption, "ul", Derivative.ul)
-_set_attr_and_docstring(EuropeanBinaryOption, "list", Derivative.list)
-_set_docstring(EuropeanBinaryOption, "payoff", Derivative.payoff)
+_set_attr_and_docstring(EuropeanBinaryOption, "simulate", BaseDerivative.simulate)
+_set_attr_and_docstring(EuropeanBinaryOption, "to", BaseDerivative.to)
+_set_attr_and_docstring(EuropeanBinaryOption, "ul", BaseDerivative.ul)
+_set_attr_and_docstring(EuropeanBinaryOption, "list", BaseDerivative.list)
+_set_docstring(EuropeanBinaryOption, "payoff", BaseDerivative.payoff)
 _set_attr_and_docstring(EuropeanBinaryOption, "moneyness", BaseOption.moneyness)
 _set_attr_and_docstring(EuropeanBinaryOption, "log_moneyness", BaseOption.log_moneyness)
 _set_attr_and_docstring(
