@@ -16,7 +16,7 @@ from ._base import BSModuleMixin
 
 
 class BSAmericanBinaryOption(BSModuleMixin):
-    """Black-Scholes formula for an American Binary Option.
+    """Black-Scholes formula for an american binary option.
 
     Note:
         Risk-free rate is set to zero.
@@ -39,11 +39,10 @@ class BSAmericanBinaryOption(BSModuleMixin):
           Corresponding derivative.
 
     References:
-        - Dai, M., 2000. A closed-form solution for perpetual American floating strike
-          lookback options. Journal of Computational Finance, 4(2), pp.63-68.
+        - Shreve, S.E., 2004. Stochastic calculus for finance II:
+          Continuous-time models (Vol. 11). Springer Science & Business Media.
 
     Examples:
-
         >>> from pfhedge.nn import BSAmericanBinaryOption
         >>>
         >>> m = BSAmericanBinaryOption(strike=1.0)
@@ -54,9 +53,9 @@ class BSAmericanBinaryOption(BSModuleMixin):
         ...     [ 0.00,  0.00, 0.1, 0.2],
         ...     [ 0.01,  0.01, 0.1, 0.2]])
         >>> m(input)
-        tensor([[1.1285],
-                [0.0000],
-                [0.0000]])
+        tensor([[...],
+                [...],
+                [...]])
     """
 
     def __init__(self, call: bool = True, strike: float = 1.0):
@@ -81,7 +80,6 @@ class BSAmericanBinaryOption(BSModuleMixin):
             BSAmericanBinaryOption
 
         Examples:
-
             >>> from pfhedge.instruments import BrownianStock
             >>> from pfhedge.instruments import AmericanBinaryOption
             >>>
@@ -123,15 +121,14 @@ class BSAmericanBinaryOption(BSModuleMixin):
         Returns:
             torch.Tensor
         """
-        s, m, t, v = broadcast_all(
-            log_moneyness, max_log_moneyness, time_to_maturity, volatility
-        )
+        # This formula is derived using the results in Section 7.3.3 of Shreve's book.
+        # Price is I_2 - I_4 where the interval of integration is [k --> -inf, b].
+        # By this substitution we get N([log(S(0) / K) + ...] / sigma T) --> 1.
 
-        n1 = ncdf(d1(s, t, v) / sqrt(2))
-        n2 = ncdf(d2(s, t, v) / sqrt(2))
-        p = (1 / 2) * (s.exp() * (1 + n1) + n2)
+        s, t, v = broadcast_all(log_moneyness, time_to_maturity, volatility)
+        p = ncdf(d2(s, t, v)) + s.exp() * (1 - ncdf(d2(-s, t, v)))
 
-        return p.where(m < 0, torch.ones_like(p))
+        return p.where(max_log_moneyness < 0, torch.ones_like(p))
 
     def delta(
         self,
@@ -159,16 +156,15 @@ class BSAmericanBinaryOption(BSModuleMixin):
         Returns:
             torch.Tensor
         """
-        s, m, t, v = broadcast_all(
-            log_moneyness, max_log_moneyness, time_to_maturity, volatility
+        s, t, v = broadcast_all(log_moneyness, time_to_maturity, volatility)
+        spor = s.exp() * self.strike
+        p = (
+            npdf(d2(s, t, v)) / (spor * v * t.sqrt())
+            - (1 - ncdf(d2(-s, t, v))) / self.strike
+            + npdf(d2(-s, t, v)) / (self.strike * v * t.sqrt())
         )
 
-        c1 = ncdf(d1(s, t, v) / sqrt(2))
-        p1 = npdf(d1(s, t, v) / sqrt(2))
-        p2 = npdf(d2(s, t, v) / sqrt(2))
-        d = (1 + c1 + (p1 + p2)) / (2 * self.strike)
-
-        return d.where(m < 0, torch.zeros_like(d))
+        return p.where(max_log_moneyness < 0, torch.zeros_like(p))
 
     @torch.enable_grad()
     def gamma(
@@ -205,6 +201,79 @@ class BSAmericanBinaryOption(BSModuleMixin):
             volatility=volatility,
         )
 
+    @torch.enable_grad()
+    def vega(
+        self,
+        log_moneyness: Tensor,
+        max_log_moneyness: Tensor,
+        time_to_maturity: Tensor,
+        volatility: Tensor,
+    ) -> Tensor:
+        """Returns vega of the derivative.
+
+        Args:
+            log_moneyness (torch.Tensor): Log moneyness of the underlying asset.
+            max_log_moneyness (torch.Tensor): Cumulative maximum of the log moneyness.
+            time_to_maturity (torch.Tensor): Time to expiry of the option.
+            volatility (torch.Tensor): Volatility of the underlying asset.
+
+        Shape:
+            - log_moneyness: :math:`(N, *)` where
+              :math:`*` means any number of additional dimensions.
+            - max_log_moneyness: :math:`(N, *)`
+            - time_to_maturity: :math:`(N, *)`
+            - volatility: :math:`(N, *)`
+            - output: :math:`(N, *)`
+
+        Returns:
+            torch.Tensor
+        """
+        return super().vega(
+            strike=self.strike,
+            log_moneyness=log_moneyness,
+            max_log_moneyness=max_log_moneyness,
+            time_to_maturity=time_to_maturity,
+            volatility=volatility,
+        )
+
+    @torch.enable_grad()
+    def theta(
+        self,
+        log_moneyness: Tensor,
+        max_log_moneyness: Tensor,
+        time_to_maturity: Tensor,
+        volatility: Tensor,
+    ) -> Tensor:
+        """Returns theta of the derivative.
+
+        Args:
+            log_moneyness (torch.Tensor): Log moneyness of the underlying asset.
+            max_log_moneyness (torch.Tensor): Cumulative maximum of the log moneyness.
+            time_to_maturity (torch.Tensor): Time to expiry of the option.
+            volatility (torch.Tensor): Volatility of the underlying asset.
+
+        Shape:
+            - log_moneyness: :math:`(N, *)` where
+              :math:`*` means any number of additional dimensions.
+            - max_log_moneyness: :math:`(N, *)`
+            - time_to_maturity: :math:`(N, *)`
+            - volatility: :math:`(N, *)`
+            - output: :math:`(N, *)`
+
+        Note:
+            Risk-free rate is set to zero.
+
+        Returns:
+            torch.Tensor
+        """
+        return super().theta(
+            strike=self.strike,
+            log_moneyness=log_moneyness,
+            max_log_moneyness=max_log_moneyness,
+            time_to_maturity=time_to_maturity,
+            volatility=volatility,
+        )
+
     def implied_volatility(
         self,
         log_moneyness: Tensor,
