@@ -22,6 +22,15 @@ class BSEuropeanBinaryOption(BSModuleMixin):
     Note:
         Risk-free rate is set to zero.
 
+    .. seealso::
+        - :class:`pfhedge.nn.BlackScholes`:
+          Initialize Black-Scholes formula module from a derivative.
+        - :class:`pfhedge.instruments.EuropeanBinaryOption`:
+          Corresponding derivative.
+
+    References:
+        - John C. Hull, 2003. Options futures and other derivatives. Pearson.
+
     Args:
         call (bool, default=True): Specifies whether the option is call or put.
         strike (float, default=1.0): The strike price of the option.
@@ -33,17 +42,7 @@ class BSEuropeanBinaryOption(BSModuleMixin):
         - Output: :math:`(N, *, 1)`.
           All but the last dimension are the same shape as the input.
 
-    .. seealso::
-        - :class:`pfhedge.nn.BlackScholes`:
-          Initialize Black-Scholes formula module from a derivative.
-        - :class:`pfhedge.instruments.EuropeanBinaryOption`:
-          Corresponding derivative.
-
-    References:
-        - John C. Hull, 2003. Options futures and other derivatives. Pearson.
-
     Examples:
-
         >>> from pfhedge.nn import BSEuropeanBinaryOption
         >>>
         >>> m = BSEuropeanBinaryOption(strike=1.0)
@@ -60,11 +59,6 @@ class BSEuropeanBinaryOption(BSModuleMixin):
     """
 
     def __init__(self, call: bool = True, strike: float = 1.0):
-        if not call:
-            raise ValueError(
-                f"{self.__class__.__name__} for a put option is not yet supported."
-            )
-
         super().__init__()
         self.call = call
         self.strike = strike
@@ -81,7 +75,6 @@ class BSEuropeanBinaryOption(BSModuleMixin):
             BSEuropeanBinaryOption
 
         Examples:
-
             >>> from pfhedge.instruments import BrownianStock
             >>> from pfhedge.instruments import EuropeanBinaryOption
             >>>
@@ -94,6 +87,8 @@ class BSEuropeanBinaryOption(BSModuleMixin):
 
     def extra_repr(self) -> str:
         params = []
+        if not self.call:
+            params.append("call=" + str(self.call))
         params.append("strike=" + _format_float(self.strike))
         return ", ".join(params)
 
@@ -148,7 +143,10 @@ class BSEuropeanBinaryOption(BSModuleMixin):
         """
         s, t, v = broadcast_all(log_moneyness, time_to_maturity, volatility)
 
-        delta = npdf(d2(s, t, v)) / (self.strike * s.exp() * v * t.sqrt())
+        spot = s.exp() * self.strike
+        delta = npdf(d2(s, t, v)) / (spot * v * t.sqrt())
+        delta = -delta if not self.call else delta  # put-call parity
+
         return delta
 
     def gamma(
@@ -170,6 +168,7 @@ class BSEuropeanBinaryOption(BSModuleMixin):
         Returns:
             torch.Tensor
         """
+        # TODO(simaki): Directly compute gamma.
         return super().gamma(
             strike=self.strike,
             log_moneyness=log_moneyness,
@@ -177,6 +176,63 @@ class BSEuropeanBinaryOption(BSModuleMixin):
             volatility=volatility,
         )
 
+    def vega(
+        self, log_moneyness: Tensor, time_to_maturity: Tensor, volatility: Tensor
+    ) -> Tensor:
+        """Returns vega of the derivative.
+
+        Args:
+            log_moneyness (torch.Tensor): Log moneyness of the underlying asset.
+            time_to_maturity (torch.Tensor): Time to expiry of the option.
+            volatility (torch.Tensor): Volatility of the underlying asset.
+
+        Shape:
+            - log_moneyness: :math:`(N, *)`
+            - time_to_maturity: :math:`(N, *)`
+            - volatility: :math:`(N, *)`
+            - output: :math:`(N, *)`
+
+        Returns:
+            torch.Tensor
+        """
+        # TODO: Directly compute theta.
+        return super().vega(
+            strike=self.strike,
+            log_moneyness=log_moneyness,
+            time_to_maturity=time_to_maturity,
+            volatility=volatility,
+        )
+
+    def theta(
+        self, log_moneyness: Tensor, time_to_maturity: Tensor, volatility: Tensor
+    ) -> Tensor:
+        """Returns theta of the derivative.
+
+        Args:
+            log_moneyness (torch.Tensor): Log moneyness of the underlying asset.
+            time_to_maturity (torch.Tensor): Time to expiry of the option.
+            volatility (torch.Tensor): Volatility of the underlying asset.
+
+        Shape:
+            - log_moneyness: :math:`(N, *)`
+            - time_to_maturity: :math:`(N, *)`
+            - volatility: :math:`(N, *)`
+            - output: :math:`(N, *)`
+
+        Note:
+            Risk-free rate is set to zero.
+
+        Returns:
+            torch.Tensor
+        """
+        # TODO: Directly compute theta.
+        return super().theta(
+            strike=self.strike,
+            log_moneyness=log_moneyness,
+            time_to_maturity=time_to_maturity,
+            volatility=volatility,
+        )
+
     def implied_volatility(
         self,
         log_moneyness: Tensor,
