@@ -21,9 +21,8 @@ from pfhedge._utils.str import _format_float
 from pfhedge._utils.typing import TensorOrScalar
 from pfhedge.features import FeatureList
 from pfhedge.features._base import Feature
-from pfhedge.instruments.base import Instrument
-from pfhedge.instruments.derivative.base import Derivative
-from pfhedge.instruments.primary.base import Primary
+from pfhedge.instruments.base import BaseInstrument
+from pfhedge.instruments.derivative.base import BaseDerivative
 from pfhedge.nn.functional import terminal_value
 
 from .loss import EntropicRiskMeasure
@@ -92,7 +91,6 @@ class Hedger(Module):
           inputs=['log_moneyness', 'time_to_maturity', 'volatility', 'prev_hedge']
           (model): WhalleyWilmott(
             (bs): BSEuropeanOption(strike=1.)
-            (clamp): Clamp()
           )
           (criterion): EntropicRiskMeasure()
         )
@@ -134,7 +132,7 @@ class Hedger(Module):
         tensor(...)
 
         It is possible to hedge a derivative with another listed derivative by
-        ``Derivative.list()`` method.
+        ``list()`` method.
 
         >>> from pfhedge.instruments import LookbackOption
         >>> from pfhedge.nn import BlackScholes
@@ -207,7 +205,7 @@ class Hedger(Module):
     def extra_repr(self) -> str:
         return "inputs=" + str(self.inputs)
 
-    def get_input(self, derivative: Derivative, time_step: Optional[int]) -> Tensor:
+    def get_input(self, derivative: BaseDerivative, time_step: Optional[int]) -> Tensor:
         """Returns the input tensor to the model at the given time step.
 
         Note:
@@ -218,7 +216,7 @@ class Hedger(Module):
             before calling this method.
 
         Args:
-            derivative (Derivative): The derivative used for getting the input.
+            derivative (BaseDerivative): The derivative used for getting the input.
             time_step (int, optional): The time step to get the input tensor.
                 If ``None`` an input tensor for all time steps is returned.
 
@@ -248,14 +246,14 @@ class Hedger(Module):
         return self.inputs.of(derivative=derivative).get(time_step)
 
     def compute_hedge(
-        self, derivative: Derivative, hedge: Optional[List[Instrument]] = None
+        self, derivative: BaseDerivative, hedge: Optional[List[BaseInstrument]] = None
     ) -> Tensor:
         """Compute the hedge ratio at each time step.
         It assumes that the derivative is already simulated.
 
         Args:
-            derivative (Derivative): The derivative to hedge.
-            hedge (Instrument, optional): The hedging instrument.
+            derivative (BaseDerivative): The derivative to hedge.
+            hedge (BaseInstrument, optional): The hedging instrument.
                 If ``None`` (default), use ``derivative.underlier``.
 
         Shape:
@@ -286,7 +284,9 @@ class Hedger(Module):
                     [0.5056, 0.3785, 0.4609, 0.5239, 0.7281, 0.7281]])
         """
         inputs = self.inputs.of(derivative, self)
-        hedge = cast(List[Instrument], [derivative.ul()] if hedge is None else hedge)
+        hedge = cast(
+            List[BaseInstrument], [derivative.ul()] if hedge is None else hedge
+        )
 
         # Check that the spot prices of the hedges have the same sizes
         if not all(h.spot.size() == hedge[0].spot.size() for h in hedge):
@@ -318,8 +318,8 @@ class Hedger(Module):
 
     def compute_pnl(
         self,
-        derivative: Derivative,
-        hedge: Optional[List[Instrument]] = None,
+        derivative: BaseDerivative,
+        hedge: Optional[List[BaseInstrument]] = None,
         n_paths: int = 1000,
         init_state: Optional[Tuple[TensorOrScalar, ...]] = None,
     ) -> Tensor:
@@ -331,8 +331,8 @@ class Hedger(Module):
         terminal portyol value after hedging a derivative.
 
         Args:
-            derivative (Derivative): The derivative to hedge.
-            hedge (list[Instrument], optional): The hedging instruments.
+            derivative (BaseDerivative): The derivative to hedge.
+            hedge (list[BaseInstrument], optional): The hedging instruments.
                 If ``None`` (default), use ``[derivative.underlier]``.
             n_paths (int, default=1000): The number of simulated price paths of the
                 underlying instrument.
@@ -361,7 +361,9 @@ class Hedger(Module):
             tensor([..., ...])
         """
         derivative.simulate(n_paths=n_paths, init_state=init_state)
-        hedge = cast(List[Instrument], [derivative.ul()] if hedge is None else hedge)
+        hedge = cast(
+            List[BaseInstrument], [derivative.ul()] if hedge is None else hedge
+        )
 
         unit = self.compute_hedge(derivative, hedge=hedge)
 
@@ -373,8 +375,8 @@ class Hedger(Module):
 
     def compute_loss(
         self,
-        derivative: Derivative,
-        hedge: Optional[List[Instrument]] = None,
+        derivative: BaseDerivative,
+        hedge: Optional[List[BaseInstrument]] = None,
         n_paths: int = 1000,
         n_times: int = 1,
         init_state: Optional[Tuple[TensorOrScalar, ...]] = None,
@@ -387,8 +389,8 @@ class Hedger(Module):
         where ``pnl`` is given by :meth:`compute_pnl`.
 
         Args:
-            derivative (Derivative): The derivative to hedge.
-            hedge (list[Instrument], optional): The hedging instruments.
+            derivative (BaseDerivative): The derivative to hedge.
+            hedge (list[BaseInstrument], optional): The hedging instruments.
                 If ``None`` (default), use ``[derivative.underlier]``.
             n_paths (int, default=1000): The number of simulated price paths of the
                 underlying instrument.
@@ -432,7 +434,7 @@ class Hedger(Module):
 
     def _configure_optimizer(
         self,
-        derivative: Derivative,
+        derivative: BaseDerivative,
         optimizer: Union[Optimizer, Callable[..., Optimizer]],
     ) -> Optimizer:
         if not isinstance(optimizer, Optimizer):
@@ -450,8 +452,8 @@ class Hedger(Module):
 
     def fit(
         self,
-        derivative: Derivative,
-        hedge: Optional[List[Instrument]] = None,
+        derivative: BaseDerivative,
+        hedge: Optional[List[BaseInstrument]] = None,
         n_epochs: int = 100,
         n_paths: int = 1000,
         n_times: int = 1,
@@ -459,6 +461,7 @@ class Hedger(Module):
         init_state: Optional[Tuple[TensorOrScalar, ...]] = None,
         verbose: bool = True,
         validation: bool = True,
+        tqdm_kwargs: dict = {},
     ) -> Optional[List[float]]:
         """Fit the hedging model to hedge a given derivative.
 
@@ -469,8 +472,8 @@ class Hedger(Module):
         validation loss after each simulation.
 
         Args:
-            derivative (Derivative): The derivative to hedge.
-            hedge (list[Instrument], optional): The hedging instruments.
+            derivative (BaseDerivative): The derivative to hedge.
+            hedge (list[BaseInstrument], optional): The hedging instruments.
                 If ``None`` (default), use ``[derivative.underlier]``.
             n_epochs (int, default=100): Number of Monte-Carlo simulations.
             n_paths (int, default=1000): The number of simulated price paths of the
@@ -487,6 +490,8 @@ class Hedger(Module):
                 standard output.
             validation (bool, default=True): If ``False``, skip the computation of the
                 validation loss and returns ``None``.
+            tqdm_kwargs (dict, default={}): Keyword argument passed to ``tqdm.__init__``
+                to customize the progress bar.
 
         Returns:
             list[float]
@@ -544,7 +549,7 @@ class Hedger(Module):
             )
 
         history = []
-        progress = tqdm(range(n_epochs), disable=not verbose)
+        progress = tqdm(range(n_epochs), disable=not verbose, **tqdm_kwargs)
         for _ in progress:
             # Compute training loss and backpropagate
             self.train()
@@ -565,8 +570,8 @@ class Hedger(Module):
 
     def price(
         self,
-        derivative: Derivative,
-        hedge: Optional[List[Instrument]] = None,
+        derivative: BaseDerivative,
+        hedge: Optional[List[BaseInstrument]] = None,
         n_paths: int = 1000,
         n_times: int = 1,
         init_state: Optional[Tuple[TensorOrScalar, ...]] = None,
@@ -575,8 +580,8 @@ class Hedger(Module):
         """Evaluate the premium of the given derivative.
 
         Args:
-            derivative (Derivative): The derivative to price.
-            hedge (list[Instrument], optional): The hedging instruments.
+            derivative (BaseDerivative): The derivative to price.
+            hedge (list[BaseInstrument], optional): The hedging instruments.
                 If ``None`` (default), use ``[derivative.underlier]``.
             n_paths (int, default=1000): The number of simulated price paths of the
                 underlying instrument.
