@@ -2,3 +2,5 @@ from .brownian import generate_brownian
 from .brownian import generate_geometric_brownian
 from .cir import generate_cir
 from .heston import generate_heston
+from .random import randn_antithetic
+from .random import randn_sobol_boxmuller
