@@ -1,3 +1,5 @@
+from typing import Any
+from typing import Callable
 from typing import Optional
 from typing import Tuple
 from typing import Union
@@ -6,25 +8,25 @@ from typing import cast
 import torch
 from torch import Tensor
 
-TensorOrFloat = Union[Tensor, float]
+from pfhedge._utils.typing import TensorOrScalar
 
 
 def generate_brownian(
     n_paths: int,
     n_steps: int,
-    init_state: Union[Tuple[TensorOrFloat, ...], TensorOrFloat] = (0.0,),
+    init_state: Union[Tuple[TensorOrScalar, ...], TensorOrScalar] = (0.0,),
     sigma: float = 0.2,
     dt: float = 1 / 250,
     dtype: Optional[torch.dtype] = None,
     device: Optional[torch.device] = None,
+    engine: Callable[..., Tensor] = torch.randn,
 ) -> Tensor:
-    """Returns time series following the Brownian motion.
+    r"""Returns time series following the Brownian motion.
 
     The time evolution of the process is given by:
 
     .. math::
-
-        dS(t) = \\sigma dW(t) \\,.
+        dS(t) = \sigma dW(t) \,.
 
     Args:
         n_paths (int): The number of simulated paths.
@@ -33,7 +35,7 @@ def generate_brownian(
             the time series.
             This is specified by a tuple :math:`(S(0),)`.
             It also accepts a :class:`torch.Tensor` or a :class:`float`.
-        sigma (float, default=0.2): The parameter :math:`\\sigma`,
+        sigma (float, default=0.2): The parameter :math:`\sigma`,
             which stands for the volatility of the time series.
         dt (float, default=1/250): The intervals of the time steps.
         dtype (torch.dtype, optional): The desired data type of returned tensor.
@@ -44,6 +46,11 @@ def generate_brownian(
             (see :func:`torch.set_default_tensor_type()`).
             ``device`` will be the CPU for CPU tensor types and the current CUDA device
             for CUDA tensor types.
+        engine (callable, default=torch.randn): The desired generator of random numbers
+            from a standard normal distribution.
+            A function call ``engine(size, dtype=None, device=None)``
+            should return a tensor filled with random numbers
+            from a standard normal distribution.
 
     Shape:
         - Output: :math:`(N, T)` where
@@ -54,7 +61,6 @@ def generate_brownian(
         torch.Tensor
 
     Examples:
-
         >>> from pfhedge.stochastic import generate_brownian
         >>>
         >>> _ = torch.manual_seed(42)
@@ -72,27 +78,29 @@ def generate_brownian(
     init_state = tuple(map(lambda t: t.to(dtype=dtype, device=device), init_state))
 
     init_value = init_state[0]
-    randn = torch.randn((n_paths, n_steps), dtype=dtype, device=device)
+    # randn = torch.randn((n_paths, n_steps), dtype=dtype, device=device)
+    randn = engine((n_paths, n_steps), dtype=dtype, device=device)
     randn[:, 0] = 0.0
-    return sigma * torch.tensor(dt).to(randn).sqrt() * randn.cumsum(1) + init_value
+    return sigma * randn.new_tensor(dt).sqrt() * randn.cumsum(1) + init_value
 
 
 def generate_geometric_brownian(
     n_paths: int,
     n_steps: int,
-    init_state: Union[Tuple[TensorOrFloat, ...], TensorOrFloat] = (1.0,),
+    init_state: Union[Tuple[TensorOrScalar, ...], TensorOrScalar] = (1.0,),
     sigma: float = 0.2,
     dt: float = 1 / 250,
     dtype: Optional[torch.dtype] = None,
     device: Optional[torch.device] = None,
+    engine: Callable[..., Tensor] = torch.randn,
 ) -> Tensor:
-    """Returns time series following the geometric Brownian motion.
+    r"""Returns time series following the geometric Brownian motion.
 
     The time evolution of the process is given by:
 
     .. math::
 
-        dS(t) = \\sigma S(t) dW(t) \\,.
+        dS(t) = \sigma S(t) dW(t) \,.
 
     Args:
         n_paths (int): The number of simulated paths.
@@ -112,6 +120,11 @@ def generate_geometric_brownian(
             (see :func:`torch.set_default_tensor_type()`).
             ``device`` will be the CPU for CPU tensor types and the current CUDA device
             for CUDA tensor types.
+        engine (callable, default=torch.randn): The desired generator of random numbers
+            from a standard normal distribution.
+            A function call ``engine(size, dtype=None, device=None)``
+            should return a tensor filled with random numbers
+            from a standard normal distribution.
 
     Shape:
         - Output: :math:`(N, T)` where
@@ -122,7 +135,6 @@ def generate_geometric_brownian(
         torch.Tensor
 
     Examples:
-
         >>> from pfhedge.stochastic import generate_brownian
         >>>
         >>> _ = torch.manual_seed(42)
@@ -147,6 +159,7 @@ def generate_geometric_brownian(
         dt=dt,
         dtype=dtype,
         device=device,
+        engine=engine,
     )
-    t = dt * torch.arange(n_steps).to(brownian).reshape(1, -1)
-    return init_state[0] * (brownian - (sigma ** 2) * t / 2).exp()
+    t = dt * torch.arange(n_steps).to(brownian).unsqueeze(0)
+    return init_state[0] * (brownian - (sigma**2) * t / 2).exp()
